/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's Life Sentences *
* in the Federal System 2022 report 5 year file and create a SAS dataset.                *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\USSC_Life5yr_Public.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = USSC_Life5yr_Public ;

DATA library.&dataset ;
INFILE datafile LRECL=310;
INPUT
   ANYFEDCNVT  1-3          ANYJUVYHX  4-6           ANYVIOLENTHX  7-9     
   CHSET  10-12             CNTVIOLENTHX  13-15      DEATHINJ  16-18       
   DEFACTO  19-21           DURATION  22-24          FIRSTCONVICT  25-27   
   LIFE  28-30              LIFE_GLMAX  31-33        LIFE_GLMIN  34-36     
   LIFE_STATMAX  37-39      LIFE_STATMIN  40-42      LIFECAT  43-45        
   P_ASSAULT  46-48         P_BURGLARY  49-51        P_DRUGPOSS  52-54     
   P_DRUGTRAFF  55-57       P_DUI  58-60             P_FRAUD  61-63        
   P_HOMICIDE  64-66        P_IMMIG  67-69           P_LARCENY  70-72      
   P_OTHER  73-75           P_OTHDRUG  76-78         P_OTHPROP  79-81      
   P_OTHVIOLENT  82-84      P_PUBORDER  85-87        P_RAPE  88-90         
   P_ROBBERY  91-93         P_TRAFFIC  94-96         P_WEAPON  97-99       
   SENT100  100-102         CHFY  103-106            FY  107-110           
   OFFGUIDE  111-114        SENTRNGE  115-118        VIOLENT  119-122      
   SENTTOT  123-130         USSCIDN  131-137         ACCAP  138-141        
   ACCTRESP  142-145        AGE  146-149             ATRB_5K  150-153      
   CAROFFAP  154-157        COMBDRG2  158-161        CRIMHIST  162-165     
   MONSEX  166-169          NEWCIT  170-173          NEWCNVTN  174-177     
   NEWEDUC  178-181         NEWRACE  182-185         SEXCAP  186-189       
   SOURCES  190-193         TOTCHPTS  194-197        WEAPON  198-201       
   XCRHISSR  202-205        XFOLSOR  206-209         AMENDYR  210-214      
   GLMIN  215-219           GLMAX  220-224           STATMAX  225-229      
   STATMIN  230-234         XMAXSOR  235-239         XMINSOR  240-244      
   ADJ_FHI  245-248         AGGROLHI  249-252        MITROLHI  253-256     
   OFFVCTHI  257-260        RSTRVCHI  261-264        TERORHI  265-268      
   VULVCTHI  269-272        BASLNHI  273-276         BASLNRHI  277-280     
   GDLINEHI $ 281-286       GDREFHI $ 287-292        WGT1  293-304         
   EVENTNUM  305-307        CHAGE1  308-310        ;                       

LABEL
   ANYFEDCNVT = "Any Federal CH Event"
   ANYJUVYHX = "Any Juvenile CH Event"
   ANYVIOLENTHX = "Any Violent CH Event"
   CNTVIOLENTHX = "Number of Violent CH Events"
   DEFACTO = "De Facto Life(>470m) - excluding Actual Life"
   DURATION = "Length of Criminal Involvement (Years)"
   FIRSTCONVICT = "Current Sentence is First Criminal Conviction"
   LIFE = "Actual Life Sentence"
   LIFE_GLMAX = "Guideline	Maximum of Life"
   LIFE_GLMIN = "Guideline Minimum of Life"
   LIFE_STATMAX = "Statutory Maximum of Life"
   LIFE_STATMIN = "Statutory Minimum of Life"
   LIFECAT = "Actual, De Facto(>470m), and Less than Life"
   USSCIDN = "USSCIDN"
   MONSEX = "MONSEX"
   SOURCES = "SOURCES"
   TOTCHPTS = "TOTCHPTS"
   XCRHISSR = "XCRHISSR"
   XFOLSOR = "XFOLSOR"
   AMENDYR = "AMENDYR"
   STATMAX = "MONMAX"
   STATMIN = "MONMIN"
   XMAXSOR = "XMAXSOR"
   XMINSOR = "XMINSOR"
   OFFVCTHI = "Official Victim"
   RSTRVCHI = "Restraint of Victim"
   VULVCTHI = "Vulnerable Victim/Hate Crime"
;

LENGTH
   ANYFEDCNVT 3             ANYJUVYHX 3              ANYVIOLENTHX 3        
   CHSET 3                  CNTVIOLENTHX 3           DEATHINJ 3            
   DEFACTO 3                DURATION 3               FIRSTCONVICT 3        
   LIFE 3                   LIFE_GLMAX 3             LIFE_GLMIN 3          
   LIFE_STATMAX 3           LIFE_STATMIN 3           LIFECAT 3             
   P_ASSAULT 3              P_BURGLARY 3             P_DRUGPOSS 3          
   P_DRUGTRAFF 3            P_DUI 3                  P_FRAUD 3             
   P_HOMICIDE 3             P_IMMIG 3                P_LARCENY 3           
   P_OTHER 3                P_OTHDRUG 3              P_OTHPROP 3           
   P_OTHVIOLENT 3           P_PUBORDER 3             P_RAPE 3              
   P_ROBBERY 3              P_TRAFFIC 3              P_WEAPON 3            
   SENT100 3                CHFY 4                   FY 4                  
   OFFGUIDE 3               SENTRNGE 3               VIOLENT 3             
   USSCIDN 6                ACCAP 3                  ACCTRESP 3            
   AGE 3                    ATRB_5K 3                CAROFFAP 3            
   COMBDRG2 3               CRIMHIST 3               MONSEX 3              
   NEWCIT 3                 NEWCNVTN 3               NEWEDUC 3             
   NEWRACE 3                SEXCAP 3                 SOURCES 3             
   TOTCHPTS 3               WEAPON 3                 XCRHISSR 3            
   XFOLSOR 3                AMENDYR 4                GLMIN 4               
   GLMAX 4                  STATMAX 6                STATMIN 4             
   XMAXSOR 4                XMINSOR 4                ADJ_FHI 3             
   AGGROLHI 3               MITROLHI 3               OFFVCTHI 3            
   RSTRVCHI 3               TERORHI 3                VULVCTHI 3            
   BASLNHI 3                BASLNRHI 3               EVENTNUM 4            
   CHAGE1 3 ;

          

RUN ;
